/*
*    Copyright (c) <2002-2003> <Jean-Philippe Barrette-LaPierre>
*    
*    Permission is hereby granted, free of charge, to any person obtaining
*    a copy of this software and associated documentation files 
*    (curlpp), to deal in the Software without restriction, 
*    including without limitation the rights to use, copy, modify, merge,
*    publish, distribute, sublicense, and/or sell copies of the Software,
*    and to permit persons to whom the Software is furnished to do so, 
*    subject to the following conditions:
*    
*    The above copyright notice and this permission notice shall be included
*    in all copies or substantial portions of the Software.
*    
*    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
*    OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
*    IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY 
*    CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
*    TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
*    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#include "exception.hpp"

curlpp::runtime_error::runtime_error( const char *reason )
    : curlpp::exception(reason)
{}

curlpp::runtime_error::runtime_error( const std::string &reason )
    : curlpp::exception(reason)
{}

curlpp::logic_error::logic_error( const char *reason )
    : curlpp::exception(reason)
{}

curlpp::logic_error::logic_error( const std::string &reason )
    : curlpp::exception(reason)
{}

curlpp::libcurl_runtime_error::libcurl_runtime_error( const std::string &reason, CURLcode code )
    : curlpp::runtime_error(reason)
    , m_code(code)
{}

curlpp::libcurl_runtime_error::libcurl_runtime_error( const char *reason, CURLcode code )
    : curlpp::runtime_error(reason)
    , m_code(code)
{}

curlpp::CURLcode curlpp::libcurl_runtime_error::what_code() const throw()
{
   return m_code;
}

curlpp::libcurl_logic_error::libcurl_logic_error( const std::string &reason, curlpp::CURLcode code )
    : curlpp::logic_error(reason)
    , m_code(code)
{}

curlpp::libcurl_logic_error::libcurl_logic_error( const char *reason, curlpp::CURLcode code )
    : curlpp::logic_error(reason)
    , m_code(code)
{}

curlpp::CURLcode 
curlpp::libcurl_logic_error::what_code() const throw()
{
   return m_code;
}

void 
curlpp::libcurl_runtime_assert( const std::string &reason, curlpp::CURLcode code )
{
   if ( code != CURLE_OK )
   {
      throw curlpp::libcurl_runtime_error( reason, code );
   }
}

void 
curlpp::libcurl_runtime_assert(const char *reason, curlpp::CURLcode code)
{
  if(code != CURLE_OK) {
    throw curlpp::libcurl_runtime_error(reason, code);
  }
}

void curlpp::libcurl_logic_assert( const std::string &reason, curlpp::CURLcode code )
{
   if ( code != CURLE_OK )
   {
      throw curlpp::libcurl_logic_error( reason, code );
   }
}

void curlpp::libcurl_logic_assert( const char *reason, curlpp::CURLcode code )
{
  if(code != CURLE_OK) {
    throw curlpp::libcurl_logic_error(reason, code);
  }
}

void curlpp::runtime_assert( const std::string &reason, bool is_okay )
{
   if ( !is_okay )
   {
      throw curlpp::runtime_error(reason);
   }
}

void curlpp::runtime_assert( const char *reason, bool is_okay )
{
  if(!is_okay) {
    throw curlpp::runtime_error(reason);
  }
}

void curlpp::logic_assert( const std::string &reason, bool is_okay )
{
   if ( !is_okay )
   {
      throw curlpp::logic_error( reason );
   }
}

void curlpp::logic_assert( const char *reason, bool is_okay )
{
  if(!is_okay) {
    throw curlpp::logic_error(reason);
  }
}

